@@ -167,6 +167,8 @@ def main():
     env.filters['secured'] = lambda x: len(x.get('security', [])) > 0
     env.filters['sec_def'] = lambda x: swagger['securityDefinitions'][x]
     env.filters['has_payload'] = lambda x: any(param for param in x.get('parameters', []) if param['in'] == 'body')
+    # filter params by place (body, query, ...)
+    env.filters['inside'] = lambda params, place: (p for p in params if p['in'] == place)
     swagger = safe_load(args.swagger.read_text())
 
     enums = tuple(iter_enums(swagger))
